@@ -30,7 +30,7 @@ class TestInput:
 
     @staticmethod
     @pytest.mark.xfail(
-        sys.platform == "win32", reason="Unknown Windows specific wrong result", strict=True
+        sys.platform == "win32", reason="Random unknown Windows specific wrong result", strict=False
     )
     def test_all_good_examples_recurively(capsys: pytest.CaptureFixture[str]) -> None:
         """Test all files in ``testing/examples/good`` recursively."""
